from IPython import get_ipython
import pandas as pd
import os

def general_notebook_settings():
    '''
    Function to customize settings for IPython environment.
    '''
    # Set the width of dataframe previews to maximum
    pd.set_option('display.max_rows', None)
    pd.set_option('display.max_columns', None)
    pd.set_option('display.float_format', '{:20,.2f}'.format)
    pd.set_option('display.max_colwidth', None)

    # Enable autoreloading of external functions
    ip = get_ipython()
    ip.magic("load_ext autoreload")
    ip.magic("autoreload 2")

    print("DataFrame width maximized!")
    print("Autoreloading of functions enabled!")



def activate_parent(parent_dir_name: str) -> None:
    """
    Sets the working directory to the specified parent directory if found in the current path hierarchy.

    Args:
        parent_dir_name (str): The name of the parent directory to set as the working directory.

    Raises:
        FileNotFoundError: If the specified parent directory is not found in the path hierarchy.
    """
    current_dir = os.getcwd()

    while True:
        if os.path.basename(current_dir) == parent_dir_name:
            os.chdir(current_dir)
            print(f"Working directory set to: {current_dir}")
            return
        
        parent_dir = os.path.dirname(current_dir)
        if current_dir == parent_dir:  # Reached the root directory
            break
        
        current_dir = parent_dir

    raise FileNotFoundError(f"The parent directory '{parent_dir_name}' was not found in the path hierarchy.")






from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="vpk_custom_functions",  # Replace with your package name
    version="0.0.6",  # Initial release version
    author="Vishnu Prakash",
    author_email="vishnucheppanam@gmail.com",
    description="Contains custom functions which are used repeatedly during development",
    url="https://github.com/vishnuprksh/vpk_custom_functions",  # Replace with your package URL
    packages=find_packages(),
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    download_url="https://github.com/vishnuprksh/vpk_custom_functions/archive/refs/tags/0.0.1.tar.gz",
    install_requires=[            # I get to this in a second
        'IPython',
        'pandas',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",  # Choose your license
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6'
)